"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupCronHandlers = void 0;
const logger_1 = require("./logger");
const cron = __importStar(require("node-cron"));
const guards_1 = require("./guards");
const get_module_export_1 = require("./node/get-module-export");
const cronJobs = new Map();
const setupCronHandlers = (steps, eventManager, socketServer) => {
    steps.filter(guards_1.isCronStep).forEach(async (step) => {
        const { config, filePath } = step;
        const { cron: cronExpression } = config;
        if (!cron.validate(cronExpression)) {
            logger_1.globalLogger.error('[cron handler] invalid cron expression', {
                expression: cronExpression,
                step: step.config.name
            });
            return;
        }
        logger_1.globalLogger.debug('[cron handler] setting up cron job', {
            filePath,
            step: step.config.name,
            cron: cronExpression
        });
        const task = cron.schedule(cronExpression, async () => {
            const traceId = Math.random().toString(36).substring(7);
            const logger = new logger_1.Logger(traceId, config.flows, step.config.name, socketServer);
            try {
                const handler = await (0, get_module_export_1.getModuleExport)(filePath, 'handler');
                const emit = async (event) => {
                    await eventManager.emit({
                        ...event,
                        traceId,
                        flows: config.flows,
                        logger
                    }, filePath);
                };
                if (handler) {
                    await handler({ emit, logger, traceId });
                }
                else {
                    await emit({
                        type: config.emits[0],
                        data: { timestamp: Date.now() }
                    });
                }
            }
            catch (error) {
                logger.error('[cron handler] error executing cron job', {
                    error: error.message,
                    step: step.config.name
                });
            }
        });
        cronJobs.set(step.config.name, task);
    });
    return () => {
        cronJobs.forEach((task) => task.stop());
        cronJobs.clear();
    };
};
exports.setupCronHandlers = setupCronHandlers;
