"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPythonConfig = void 0;
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
const logger_1 = require("../logger");
const getPythonConfig = (file) => {
    const getConfig = path_1.default.join(__dirname, 'get-config.py');
    return new Promise((resolve, reject) => {
        let config = null;
        const child = (0, child_process_1.spawn)('python', [getConfig, file], {
            stdio: ['inherit', 'inherit', 'inherit', 'ipc'],
        });
        child.on('message', (message) => {
            logger_1.globalLogger.debug('[Python Config] Read config', { config: message });
            config = message;
        });
        child.on('close', (code) => {
            if (code !== 0) {
                reject(new Error(`Process exited with code ${code}`));
            }
            else if (!config) {
                reject(new Error(`No config found for file ${file}`));
            }
            else {
                resolve(config);
            }
        });
    });
};
exports.getPythonConfig = getPythonConfig;
