"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MemoryStateAdapter = void 0;
class MemoryStateAdapter {
    constructor() {
        this.state = {};
    }
    async init() {
        this.state = {};
    }
    async get(traceId, key) {
        const fullKey = this._makeKey(traceId, key);
        return this.state[fullKey] ? this.state[fullKey] : null;
    }
    async set(traceId, key, value) {
        const fullKey = this._makeKey(traceId, key);
        this.state[fullKey] = value;
    }
    async delete(traceId, key) {
        const fullKey = this._makeKey(traceId, key);
        delete this.state[fullKey];
    }
    async clear(traceId) {
        const pattern = this._makeKey(traceId, '');
        for (const key in this.state) {
            if (key.startsWith(pattern)) {
                delete this.state[key];
            }
        }
    }
    async cleanup() {
        // No cleanup needed for file system
    }
    _makeKey(traceId, key) {
        return `${traceId}:${key}`;
    }
}
exports.MemoryStateAdapter = MemoryStateAdapter;
