"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RpcProcessor = void 0;
class RpcProcessor {
    constructor(child) {
        this.child = child;
        this.handlers = {};
    }
    handler(method, handler) {
        this.handlers[method] = handler;
    }
    async handle(method, input) {
        const handler = this.handlers[method];
        if (!handler) {
            throw new Error(`Handler for method ${method} not found`);
        }
        return handler(input);
    }
    response(id, result, error) {
        if (id) {
            this.child.send?.({ type: 'rpc_response', id, result, error });
        }
    }
    async init() {
        this.child.on('message', (msg) => {
            if (msg.type === 'rpc_request') {
                const { id, method, args } = msg;
                this.handle(method, args)
                    .then((result) => this.response(id, result, null))
                    .catch((error) => this.response(id, null, error));
            }
        });
    }
}
exports.RpcProcessor = RpcProcessor;
